@@ -6,5 +6,5 @@
 
 from gcp_storage_emulator.__main__ import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
